@@ -9,7 +9,7 @@
 
 
 /* A utility program originally written for the Linux OS SCSI subsystem.
-*  Copyright (C) 2000-2010 D. Gilbert
+*  Copyright (C) 2000-2011 D. Gilbert
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
@@ -23,9 +23,9 @@
 const char * sg_ansi_version_arr[] =
 {
     "no conformance claimed",
-    "SCSI-1",		/* obsolete */
-    "SCSI-2",		/* obsolete */
-    "SPC",		/* withdrawn */
+    "SCSI-1",           /* obsolete */
+    "SCSI-2",           /* obsolete */
+    "SPC",              /* withdrawn */
     "SPC-2",
     "SPC-3",
     "SPC-4",
@@ -39,7 +39,7 @@ struct sg_version_descriptor {
     const char * name;
 };
 
-/* table from SPC-4 revision 27 [sorted numerically (from Annex D.8)] */
+/* table from SPC-4 revision 28 [sorted numerically (from Annex D.8)] */
 /* Can also be obtained from : http://www.t10.org/lists/stds.txt  */
 struct sg_version_descriptor sg_version_descriptor_arr[] = {
     {0x0, "Version Descriptor not supported or No standard identified"},
@@ -184,6 +184,7 @@ struct sg_version_descriptor sg_version_descriptor_arr[] = {
     {0x4e3, "MMC-6 T10/1836-D revision 2b"},
     {0x4e5, "MMC-6 T10/1836-D revision 02g"},
     {0x500, "ADC-3 (no version claimed)"},
+    {0x502,  "ADC-3 T10/1895-D revision 04"},
     {0x520, "SSC-4 (no version claimed)"},
     {0x560, "OSD-3 (no version claimed)"},
     {0x580, "SES-3 (no version claimed)"},
@@ -215,11 +216,7 @@ struct sg_version_descriptor sg_version_descriptor_arr[] = {
     {0x917, "FCP-2 ANSI INCITS 350-2003"},
     {0x918, "FCP-2 T10/1144-D revision 8"},
     {0x920, "SST (no version claimed)"},
-    {0x935, "SST T10/1380-D revision 8b"},
-    {0x940, "SRP (no version claimed)"},
-    {0x954, "SRP T10/1415-D revision 10"},
-    {0x955, "SRP T10/1415-D revision 16a"},
-    {0x95c, "SRP ANSI INCITS 365-2002"},
+    {0x935, "SST T10/1380-D revision 8b"}, {0x940, "SRP (no version claimed)"}, {0x954, "SRP T10/1415-D revision 10"}, {0x955, "SRP T10/1415-D revision 16a"}, {0x95c, "SRP ANSI INCITS 365-2002"},
     {0x960, "iSCSI (no version claimed)"},
     {0x980, "SBP-3 (no version claimed)"},
     {0x982, "SBP-3 T10/1467-D revision 1f"},
@@ -243,6 +240,7 @@ struct sg_version_descriptor sg_version_descriptor_arr[] = {
     {0xa27, "ADT-2 T10/1742-D revision 08"},
     {0xa40, "FCP-4 (no version claimed)"},
     {0xa42, "FCP-4 T10/1828-D revision 01"},
+    {0xa44, "FCP-4 T10/1828-D revision 02"},
     {0xaa0, "SPI (no version claimed)"},
     {0xab9, "SPI T10/0855-D revision 15a"},
     {0xaba, "SPI ANSI INCITS 253-1995"},
